@@ -1,7 +1,6 @@
 define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
     
@@ -9,20 +8,17 @@ define([
     , '../../constData.js'
     , '../base/index.js'
 
-], function ( $, vpCommon, vpConst, sb, vpTableLayoutVerticalSimple,
+], function ( $, vpCommon, sb, vpTableLayoutVerticalSimple,
 
               api,  constData, baseComponent ) {
     const {  CreateOneArrayValueAndGet
             , UpdateOneArrayValueAndGet
             , DeleteOneArrayValueAndGet
 
-            , GenerateWhileConditionList } = api;
+            , GenerateWhileCode } = api;
 
-    const { BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
-            , STR_COLON_SELECTED
+    const { STR_COLON_SELECTED
 
-            , STR_SELECTED
             , STR_EMPTY
             , STR_CHANGE 
             , STR_CHANGE_KEYUP_PASTE
@@ -35,36 +31,15 @@ define([
             , VP_CLASS_STYLE_FLEX_ROW
             , VP_CLASS_STYLE_FLEX_ROW_CENTER    
             , VP_CLASS_STYLE_FLEX_ROW_BETWEEN
-            , VP_CLASS_STYLE_FLEX_ROW_END
-            , VP_CLASS_STYLE_FLEX_COLUMN_CENTER
-            , VP_CLASS_STYLE_MARGIN_TOP_5PX
-            
-            , VP_CLASS_STYLE_WIDTH_5PERCENT
+
             , VP_CLASS_STYLE_WIDTH_10PERCENT
             , VP_CLASS_STYLE_WIDTH_15PERCENT
             , VP_CLASS_STYLE_WIDTH_20PERCENT
-            , VP_CLASS_STYLE_WIDTH_25PERCENT
-            , VP_CLASS_STYLE_WIDTH_30PERCENT
-            , VP_CLASS_STYLE_WIDTH_35PERCENT
-            , VP_CLASS_STYLE_WIDTH_40PERCENT
-            , VP_CLASS_STYLE_WIDTH_45PERCENT
-            , VP_CLASS_STYLE_WIDTH_50PERCENT
-            , VP_CLASS_STYLE_WIDTH_55PERCENT
-            , VP_CLASS_STYLE_WIDTH_60PERCENT
-            , VP_CLASS_STYLE_WIDTH_65PERCENT
-            , VP_CLASS_STYLE_WIDTH_70PERCENT
-            , VP_CLASS_STYLE_WIDTH_75PERCENT
-            , VP_CLASS_STYLE_WIDTH_80PERCENT
-            , VP_CLASS_STYLE_WIDTH_85PERCENT
-            , VP_CLASS_STYLE_WIDTH_90PERCENT
-            , VP_CLASS_STYLE_WIDTH_95PERCENT
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
             , VP_CLASS_STYLE_BGCOLOR_C4C4C4
-            , VP_CLASS_APIBLOCK_BLOCK_HEADER
 
             , VP_ID_PREFIX
-            , VP_ID_APIBLOCK_OPTION_WHILE_TYPE_SELECT
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_1
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_2
@@ -72,100 +47,97 @@ define([
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_4
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_5
             , VP_ID_APIBLOCK_OPTION_WHILE_ARG_6
-            , VP_ID_APIBLOCK_OPTION_WHILE_ARG_7
             , VP_ID_APIBLOCK_OPTION_WHILE_PLUS
             , VP_ID_APIBLOCK_OPTION_WHILE_DELETE
 
             , VP_CLASS_STYLE_OPACITY_0
             , VP_CLASS_STYLE_OPACITY_1
 
-            , WHILE_BLOCK_TYPE
             , WHILE_BLOCK_SELECT_VALUE_ARG_TYPE
-            , WHILE_OPERATOR_ARG1
             , WHILE_OPERATOR_ARG2
             , COMPARISON_OPERATOR_IF_ARG4
             , COMPARISON_OPERATOR_IF_ARG6
-            , STATE_whileBlockOptionType
-            , STATE_whileCodeLine
+
             , STATE_whileConditionList
+
              } = constData;
 
     const { MakeOptionContainer
             , MakeOptionDeleteButton
             , MakeOptionPlusButton
-            , MakeVpSuggestInputText_apiblock
-            , MakeOptionInput
-            , MakeOptionSelectBox } = baseComponent;
+            , MakeVpSuggestInputText_apiblock } = baseComponent;
 
     var InitWhileBlockOption = function(thisBlock, optionPageSelector) {
-                var uuid = thisBlock.getUUID();
-                var blockContainerThis = thisBlock.getBlockContainerThis();
-                var ifConditionListState = thisBlock.getState(STATE_whileConditionList);  
+        var uuid = thisBlock.getUUID();
+        var blockContainerThis = thisBlock.getBlockContainerThis();
+        var ifConditionListState = thisBlock.getState(STATE_whileConditionList);  
            
-                /** --------------------------------- If Option 이벤트 함수 바인딩 ---------------------------------- */           
+        /** --------------------------------- If Option 이벤트 함수 바인딩 ---------------------------------- */           
         
-                /** if 변경 이벤트 함수 바인딩 */
-                ifConditionListState.forEach( ( condition, index ) => {
-                    var uuid = thisBlock.getUUID();
-                    // const { conditionType } = condition;
+        /** if 변경 이벤트 함수 바인딩 */
+        ifConditionListState.forEach( ( condition, index ) => {
+            var uuid = thisBlock.getUUID();
     
-                    /**
-                         * @event_function
-                         * iF arg2 선택 변경 
-                    */
-                        $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid);
-                        $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid, function(event) {
-                            // RenderInputRequiredColor(this);
-                            var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                            var ifConditionState = ifConditionListState[index];
-                            var selectedValue = $(STR_COLON_SELECTED, this).val();
-                            if (selectedValue == 'none') {
-                                selectedValue = STR_EMPTY;
-                            }
-                            var updatedValue = {
-                                ...ifConditionState
-                                ,arg2: selectedValue
-                            }
-                            ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                            thisBlock.setState({
-                                [STATE_whileConditionList]: ifConditionListState
-                            });
+            /**
+             * @event_function
+             * iF arg2 선택 변경 
+             */
+            $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid);
+            $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid, function(event) {
+                var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
+                var ifConditionState = ifConditionListState[index];
+                var selectedValue = $(STR_COLON_SELECTED, this).val();
+                    if (selectedValue == 'none') {
+                        selectedValue = STR_EMPTY;
+                    }
 
-                            var whileBlockCode = GenerateWhileConditionList(thisBlock);
-                            thisBlock.writeCode(whileBlockCode);
-                            blockContainerThis.renderBlockOptionTab();
-                            event.stopPropagation();
-                        });
+                    var updatedValue = {
+                        ...ifConditionState
+                        ,arg2: selectedValue
+                    }
+
+                    ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
+                    thisBlock.setState({
+                        [STATE_whileConditionList]: ifConditionListState
+                    });
+
+                    var whileBlockCode = GenerateWhileCode(thisBlock);
+                    thisBlock.writeCode(whileBlockCode);
+                    blockContainerThis.renderBlockOptionTab();
+                    event.stopPropagation();
+                });
+
+                /**
+                  * @event_function
+                  * iF arg4 선택 변경 
+                 */
+                $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid);
+                $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid, function(event) {
+                   
+                    var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
+                    var ifConditionState = ifConditionListState[index];
+                    var selectedValue = $(STR_COLON_SELECTED, this).val();
+                    if (selectedValue == 'none') {
+                        selectedValue = STR_EMPTY;
+                    }
+
+                    var updatedValue = {
+                        ...ifConditionState
+                        ,arg4: selectedValue
+                    }
+                    
+                    ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
+                    thisBlock.setState({
+                        [STATE_whileConditionList]: ifConditionListState
+                    });
+
+                    var whileBlockCode = GenerateWhileCode(thisBlock);
+                    thisBlock.writeCode(whileBlockCode);
+                    blockContainerThis.renderBlockOptionTab();
+                    event.stopPropagation();
+                });
 
-                        /**
-                         * @event_function
-                         * iF arg4 선택 변경 
-                         */
-                        $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid);
-                        $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid, function(event) {
-                            // RenderInputRequiredColor(this);
-                            var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                            var ifConditionState = ifConditionListState[index];
-                            var selectedValue = $(STR_COLON_SELECTED, this).val();
-                            if (selectedValue == 'none') {
-                                selectedValue = STR_EMPTY;
-                            }
-                            var updatedValue = {
-                                ...ifConditionState
-                                ,arg4: selectedValue
-                            }
-                            ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                            thisBlock.setState({
-                                [STATE_whileConditionList]: ifConditionListState
-                            });
 
-                            var whileBlockCode = GenerateWhileConditionList(thisBlock);
-                            thisBlock.writeCode(whileBlockCode);
-                            blockContainerThis.renderBlockOptionTab();
-                            event.stopPropagation();
-                        });
-                    // WHILE_BLOCK_TYPE
-                    // if (conditionType == WHILE_BLOCK_TYPE.CONDITION) {
                         for (var k = 1; k < 7; k++) {
                             ((i) => {
             
@@ -184,19 +156,16 @@ define([
                                                 ...ifConditionState
                                                 , arg1: inputValue
                                             }
-                                            // RenderInputRequiredColor(this);
                                         } else if (i == 2) {
                                             updatedValue = {
                                                 ...ifConditionState
                                                 , arg2: inputValue 
                                             }
-                                            // RenderInputRequiredColor(this);
                                         } else if (i == 3) {
                                             updatedValue = {
                                                 ...ifConditionState
                                                 , arg3: inputValue 
                                             }
-                                            // RenderInputRequiredColor(this);
                                         }  else if (i == 4) {
                                             
                                             updatedValue = {
@@ -222,14 +191,13 @@ define([
                                                 ...ifConditionState
                                                 , arg6: inputValue
                                             }
-                                            // RenderInputRequiredColor(this);
                                         }
             
                                         ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
                                         thisBlock.setState({
                                             [STATE_whileConditionList]: ifConditionListState
                                         });
-                                        var ifConditionCode = GenerateWhileConditionList(thisBlock);
+                                        var ifConditionCode = GenerateWhileCode(thisBlock);
                                         thisBlock.writeCode(ifConditionCode);
                                     
                                         event.stopPropagation();
@@ -237,59 +205,6 @@ define([
                 
                             })(k);
                         }       
-                    // } else {
-                        /** codeline arg6 */
-                        /** If USER input 변경 이벤트 함수 바인딩 */
-                        // $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_USER_INPUT + index + uuid);
-                        // $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_USER_INPUT + index + uuid, function(event) {
-                 
-                        //     // RenderInputRequiredColor(this);
-                   
-                        //     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                        //     var ifConditionState = ifConditionListState[index];
-                        //     var inputValue = $(this).val();
-        
-                        //     var updatedValue= {
-                        //         ...ifConditionState
-                        //         , codeLine: inputValue
-                        //     }
-                       
-        
-                        //     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                        //     thisBlock.setState({
-                        //         [STATE_whileConditionList]: ifConditionListState
-                        //     });
-                        //     var ifConditionCode = GenerateWhileConditionList(thisBlock);
-                        //     $(`.vp-block-header-${thisBlock.getUUID()}`).html(ifConditionCode);
-                        
-                        //     event.stopPropagation();
-                        // });
-        
-        
-                        // $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid);
-                        // $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid, function(event) {
-                 
-                        //     // RenderInputRequiredColor(this);
-                   
-                        //     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                        //     var ifConditionState = ifConditionListState[index];
-                        //     var inputValue = $(this).val();
-        
-                        //     var updatedValue = {
-                        //         ...ifConditionState
-                        //         , arg6: inputValue
-                        //     }
-        
-                        //     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                        //     thisBlock.setState({
-                        //         [STATE_whileConditionList]: ifConditionListState
-                        //     });
-                        //     var ifConditionCode = GenerateWhileConditionList(thisBlock);
-                        //     $(`.vp-block-header-${thisBlock.getUUID()}`).html(ifConditionCode);
-                        
-                        //     event.stopPropagation();
-                        // });
-                    // }
                            
                     /** 삭제 if condition */
                     $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_DELETE + index + uuid));
@@ -305,7 +220,7 @@ define([
                         thisBlock.setState({
                             [STATE_whileConditionList]: ifConditionListState
                         });
-                        var ifConditionCode = GenerateWhileConditionList(thisBlock);
+                        var ifConditionCode = GenerateWhileCode(thisBlock);
                         thisBlock.writeCode(ifConditionCode);
                         blockContainerThis.renderBlockOptionTab();
         
@@ -318,7 +233,7 @@ define([
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_PLUS + uuid), function(event) {
         
                     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                    thisBlock.addVariableIndex();
+      
                     var newCondition = {
                         arg1: ''
                         , arg2: ''
@@ -326,42 +241,18 @@ define([
                         , arg4: ''
                         , arg5: ''
                         , arg6: ''
-                        // , arg7: ''
-                        // , conditionType: WHILE_BLOCK_TYPE.CONDITION
                     }
                     ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
                     thisBlock.setState({
                         [STATE_whileConditionList]: ifConditionListState
                     });
-                    var ifConditionCode = GenerateWhileConditionList(thisBlock);
+                    var ifConditionCode = GenerateWhileCode(thisBlock);
                     thisBlock.writeCode(ifConditionCode);
                     
                     blockContainerThis.renderBlockOptionTab();
                     event.stopPropagation();
                 });
-        
-                // /** 생성 if condition - User Input ,arg6*/
-                // $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_PLUS_USER_INPUT + uuid));
-                // $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_PLUS_USER_INPUT + uuid), function(event) {
-        
-                //     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);
-                //     thisBlock.addVariableIndex();
-                
-                //     var newCondition = {
-                //         codeLine: ''
-                //         , arg6: ''
-                //         , conditionType: WHILE_BLOCK_TYPE.TRUE_FALSE
-                //     }
-                //     ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-                //     thisBlock.setState({
-                //         ifConditionList: ifConditionListState
-                //     });
-                //     var ifConditionCode = GenerateWhileConditionList(thisBlock);
-                //     $(`.vp-block-header-${thisBlock.getUUID()}`).html(ifConditionCode);
-                    
-                //     blockContainerThis.renderBlockOptionTab();
-                //     event.stopPropagation();
-                // });
+    
         
                 /** arg1, arg2, arg3, arg4, arg5, arg6 select 변경 if condition */
                 var bindSelectValueEventFunc_while = function(selectedValue, index, type) {
@@ -373,7 +264,7 @@ define([
                             ...ifConditionState
                             , arg1: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 + index + uuid, selectedValue);
+                        
                     } else if (type == WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2) {
                         if (selectedValue == 'none') {
                             selectedValue = STR_EMPTY;
@@ -382,13 +273,13 @@ define([
                             ...ifConditionState
                             , arg2: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid, selectedValue);
+                      
                     } else if (type == WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3) {
                         updatedValue = {
                             ...ifConditionState
                             , arg3: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid, selectedValue);
+                     
                     } else if (type == WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
                
                         if (selectedValue == 'none') {
@@ -418,13 +309,13 @@ define([
                             ...ifConditionState
                             , arg6: selectedValue 
                         }
-                        // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid, selectedValue);
+                      
                     }
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
                     thisBlock.setState({
                         [STATE_whileConditionList]: ifConditionListState
                     });
-                    var ifConditionCode = GenerateWhileConditionList(thisBlock);
+                    var ifConditionCode = GenerateWhileCode(thisBlock);
                     thisBlock.writeCode(ifConditionCode);
     
                 }
@@ -441,9 +332,6 @@ define([
                     var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
                     var ifConditionListState = thisBlock.getState(STATE_whileConditionList);   
                     ifConditionListState.forEach( (condition, index) => {
-                     
-
-                        // const { conditionType } = condition; 
              
                         var sbCondition = new sb.StringBuilder();
                         sbCondition.appendFormatLine("<div class='{0}'  ", VP_CLASS_STYLE_FLEX_ROW_BETWEEN);
@@ -452,11 +340,12 @@ define([
                         var sbConditionLeft = new sb.StringBuilder();
                         sbConditionLeft.appendFormatLine("<div class='{0}'  ", VP_CLASS_STYLE_FLEX_ROW_BETWEEN);
                         sbConditionLeft.appendFormatLine("     style='{0}'  >",'width:80%;');
-                        // var sbConditionDom = $(sbCondition.toString());
+               
                         const { arg1, arg2, arg3, arg4, arg5, arg6 } = condition; 
                         var loadedVariableNameList_arg1 = [ `'i${index + 1}'`, ...loadedVariableNameList];
                         var loadedVariableNameList_arg3 = [ `'j${index + 1}'`, ...loadedVariableNameList];
                         var loadedVariableNameList_arg5 = [ `'k${index + 1}'`, ...loadedVariableNameList];
+
                         var suggestInputArg1 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 + index + uuid
                                                                                 , arg1
                                                                                 , loadedVariableNameList_arg1
@@ -467,30 +356,9 @@ define([
                                                                                                                 index,
                                                                                                                 WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1);
                                                                                     });  
-                                                                                    
-                        var filterd_IF_OPERATOR_ARG2 = WHILE_OPERATOR_ARG2.filter(arg => {
-                            if (arg == 'none') {
-                                return false;
-                            } else {
-                                return true;
-                            }
-                        });
-                        var isSuggestInput = filterd_IF_OPERATOR_ARG2.some(arg => {
-                            if (arg == arg2) {
-                                return true;
-                            }
-                        });                                                                   
-                        var sbIfArg2;
-        
-                        // console.log('arg2',arg2);
-                        // if (isSuggestInput == true) {
-                        //     sbIfArg2 = MakeOptionSelectBox(VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid
-                        //                                 , VP_CLASS_STYLE_WIDTH_15PERCENT
-                        //                                 , arg2
-                        //                                 , WHILE_OPERATOR_ARG2);
+                                                                                                                                             
 
-                        // } else {
-                            sbIfArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid
+                        var sbIfArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid
                                             , arg2
                                             , WHILE_OPERATOR_ARG2
                                             , VP_CLASS_STYLE_WIDTH_15PERCENT
@@ -500,7 +368,7 @@ define([
                                                                         index,
                                                                         WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
                                             });     
-                        // }
+                        
                                                           
                         var suggestInputArg3 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid
                                                                                 , arg3
@@ -512,26 +380,9 @@ define([
                                                                                                                 index,
                                                                                                                 WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
                                                                                     });   
-                        // var filterd_IF_OPERATOR_ARG4 = COMPARISON_OPERATOR_IF_ARG4.filter(arg => {
-                        //     if (arg == 'none') {
-                        //         return false;
-                        //     } else {
-                        //         return true;
-                        //     }
-                        // });
-                        // var isSuggestInput = filterd_IF_OPERATOR_ARG4.some(arg => {
-                        //     if (arg == arg4) {
-                        //         return true;
-                        //     }
-                        // });
-                        var sbIfArg4;
-                        // if (isSuggestInput == true) {
-                            // sbIfArg4 = MakeOptionSelectBox(VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid
-                            //                             , VP_CLASS_STYLE_WIDTH_15PERCENT
-                            //                             , arg4
-                            //                             , COMPARISON_OPERATOR_IF_ARG4);
 
-                        // } else {
+                        var sbIfArg4;
+    
                             sbIfArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid
                                 , arg4
                                 , COMPARISON_OPERATOR_IF_ARG4
@@ -542,8 +393,7 @@ define([
                                         index,
                                         WHILE_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
                                 });    
-                        // }
-
+         
                         var suggestInputArg5 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid
                                                                                 , arg5
                                                                                 , loadedVariableNameList_arg5
@@ -597,9 +447,9 @@ define([
                     var sbButtonContainerDom = $(sbButtonContainer.toString());
         
                     var plusButton = MakeOptionPlusButton(VP_ID_APIBLOCK_OPTION_WHILE_PLUS + uuid, '+ Condition');
-                    // var plusButton_userInput = MakeOptionPlusButton(VP_ID_APIBLOCK_OPTION_WHILE_PLUS_USER_INPUT + uuid, '+ User Input', VP_CLASS_STYLE_MARGIN_LEFT_15PX);
+                  
                     sbButtonContainerDom.append(plusButton);
-                    // sbButtonContainerDom.append(plusButton_userInput);
+
         
                     optionContainerDom.append(sbButtonContainerDom);
                     /** bottom block option 탭에 렌더링된 dom객체 생성 */
@@ -621,11 +471,7 @@ define([
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid).val(arg3);
                
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 + index + uuid).val(arg5);
-                        // if (arg2 == 'none') {
-                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid).val(STR_EMPTY);
-                        // } else {
-                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid).val(arg2);
-                        // }
+
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid).val(arg2);
                         if (arg4 == '') {
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 + index + uuid).val(STR_EMPTY);
@@ -645,13 +491,7 @@ define([
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid).val(arg6);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
                         }
-              
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 + index + uuid);
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 + index + uuid);
-        
-                        // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_WHILE_USER_INPUT + index + uuid);
+            
                     });
 
 
