@@ -1,31 +1,35 @@
 define([
     'nbextensions/visualpython/src/common/constant'
 ], function ( vpConstant ) {
-    const { } = vpConstant;
 
     /** ---------------------------------------- API block에서 쓰이는 ENUM TYPE ------------------------------------------ */
+    const BLOCK_GROUP_TYPE = {
+        DEFINE: 1
+        , CONTROL: 2
+        , EXECUTE: 3
+    }
+
     const BLOCK_CODELINE_BTN_TYPE = {
         CLASS: 1
         , DEF: 2
-        , IF: 3
         , FOR: 4
         , WHILE: 5
-        , IMPORT: 6
-        , API: 7
+        , IF: 3
+
         , TRY: 8
     
-        , RETURN: 9
-        , BREAK: 10
         , CONTINUE: 11
+        , BREAK: 10
         , PASS: 12
-        , PROPERTY: 13
+        , RETURN: 9
+
+        , IMPORT: 6
         , LAMBDA: 14
-
-        , BLANK: 15
-        , COMMENT: 16
-
-        // , SAMPLE: 900
+        
         , CODE: 999
+        , PRINT: 17
+        
+        , COMMENT: 16
     }
     
     const BLOCK_CODELINE_TYPE = {
@@ -45,41 +49,31 @@ define([
         , PROPERTY: 13
 
         , LAMBDA: 14
-        , BLANK: 15
-        , COMMENT: 16
 
+        , COMMENT: 16
+        , PRINT: 17
+        
         , ELIF: 100
         , ELSE: 200
         , FOR_ELSE: 201
-        , INIT: 300
+        // , INIT: 300
         , DEL: 400
         , EXCEPT: 500
         , FINALLY: 600
 
-        // , SAMPLE: 900
-        
+        , TEXT: 990
         , CODE: 999
         
-        , HOLDER: 1000
-        , NULL: 10000
+        , SHADOW: 1000
+
+        , NODE: 100000
     }
     
     const BLOCK_DIRECTION  = {
         ROOT: -1
         , DOWN: 1
         , INDENT: 2
-        , BOTTOM_DOWN: 3
-    }
-    
-    const BLOCK_TYPE = {
-        BLOCK: 1
-        , SHADOW_BLOCK: 2
-        , MOVE_BLOCK: 3
-    }
-    
-    const MAKE_CHILD_BLOCK = {
-        MOVE: 1
-        , SHADOW: 2
+        , NONE: 100
     }
   
     const IMPORT_BLOCK_TYPE = {
@@ -90,8 +84,10 @@ define([
     const FOCUSED_PAGE_TYPE = {
         NULL: 1
         , BUTTONS: 2
-        , EDITOR: 3
+        , BOARD: 3
         , OPTION: 4
+        , BOARD_TITLE: 5
+        , API_LIST_TAB: 6
     }
 
     const DEF_BLOCK_TYPE = {
@@ -106,32 +102,7 @@ define([
         , STR: 'str'
         , INPUT_STR: 'inputStr'
     }
-
-    const DEF_BLOCK_ARG4_TYPE = {
-        NONE: 'none'
-        , INT: 'int'
-        , STR: 'str'
-        , FLOAT: 'float'
-        , BOOL: 'bool'
-        , BYTES: 'bytes'
-        , COMPLEX: 'complex'
-        , TUPLE: 'tuple'
-        , LIST: 'list'
-        , DICT: 'dict'
-        , INPUT_STR: 'inputStr'
-    }
-    const DEF_BLOCK_ARG4_TYPE_EXCEPT_INPUT_STR = {
-        NONE: 'none'
-        , INT: 'int'
-        , STR: 'str'
-        , FLOAT: 'float'
-        , BOOL: 'bool'
-        , BYTES: 'bytes'
-        , COMPLEX: 'complex'
-        , TUPLE: 'tuple'
-        , LIST: 'list'
-        , DICT: 'dict'
-    }
+    
     const DEF_BLOCK_ARG6_TYPE = {
         NONE: 'none'
         , ARGS: '*args'
@@ -140,24 +111,20 @@ define([
 
     const DEF_BLOCK_SELECT_VALUE_ARG_TYPE = {
         ARG3: 3
-        , ARG4: 4
         , ARG5: 5
         , ARG6: 6
-        , RETURN_TYPE: 7
     }
 
     const FOR_BLOCK_TYPE = {
         FOR: 'for'
-        , LIST_FOR: 'listfor'
     }
 
     const FOR_BLOCK_ARG3_TYPE = {
-        // DEFAULT: 'default'
         ZIP: 'zip'
         , RANGE: 'range'
         , ENUMERATE: 'enumerate'
-        , INPUT_STR: 'type your code'
     }
+
     const FOR_BLOCK_SELECT_VALUE_ARG_TYPE = {
         ARG1: 1
         , ARG2: 2
@@ -201,22 +168,19 @@ define([
         , ARG4: 5
     }
 
+    const WHILE_BLOCK_SELECT_VALUE_ARG_TYPE = {
+        ARG1: 1
+        , ARG2: 2
+        , ARG3: 3
+        , ARG4: 4 
+        , ARG5: 5
+        , ARG6: 6
+        , ARG7: 7
+    }
+
     const API_BLOCK_PROCESS_PRODUCTION = Symbol();
     const API_BLOCK_PROCESS_DEVELOPMENT = Symbol();
 
-    const IMPORT_LIBRARY_LIST = {
-        0: { value: 'numpy', text: 'numpy' }
-        , 1: { value: 'pandas', text: 'pandas' }
-        , 2: { value: 'matplotlib', text: 'matplotlib' }
-        , 3: { value: 'seaborn', text: 'seaborn'}
-        , 4: { value: 'os', text: 'os'}
-        , 5: { value: 'sys', text: 'sys'}
-        , 6: { value: 'time', text: 'time'}
-        , 7: { value: 'datetime', text: 'datetime'}
-        , 8: { value: 'random', text: 'random'}
-        , 9: { value: 'math', text: 'math'}
-    }
-
     /** ---------------------------------------- const Number ------------------------------------------ */
 
     const NUM_INDENT_DEPTH_PX = 20;
@@ -230,9 +194,11 @@ define([
     const NUM_THOUSAND = 1000;
     const NUM_FONT_WEIGHT_300 = 300;
     const NUM_FONT_WEIGHT_700 = 700;
+
     const NUM_DELETE_KEY_EVENT_NUMBER = 46;
-    // const NUM_DEFAULT_POS_X = 60;
-    const NUM_DEFAULT_POS_X = 75;
+    const NUM_ENTER_KEY_EVENT_NUMBER = 13;
+
+    const NUM_DEFAULT_POS_X = 32;
     const NUM_DEFAULT_POS_Y = 0;
     const NUM_DEFAULT_BLOCK_LEFT_HOLDER_HEIGHT = 42;
     const NUM_BLOCK_BOTTOM_HOLDER_HEIGHT = 10;
@@ -242,15 +208,25 @@ define([
     const NUM_SHADOWBLOCK_OPACITY = 0.4;
     const NUM_EXCEED_DEPTH = 6;
     const NUM_MAX_BLOCK_NUMBER = 9999;
-    const NUM_BLOCK_MAX_WIDTH = 300;
-    const NUM_OPTION_PAGE_WIDTH = 380;
+    const NUM_NODE_OR_TEXT_BLOCK_MARGIN_TOP_PX = 20;
+
+    const NUM_BLOCK_MAX_WIDTH = 360;
+    const NUM_APIBLOCK_MAIN_PAGE_WIDTH = 1000;
+    const NUM_APIBLOCK_LEFT_PAGE_WIDTH = 140;
+    const NUM_OPTION_PAGE_WIDTH = 225;
+
+    const NUM_BUTTONS_PAGE_WIDTH = 140;
+    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 430;
+    const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 290;
+    const NUM_TEXT_BLOCK_WIDTH = 900;
     /** ---------------------------------------- const String ------------------------------------------ */
-    const STR_NULL = '';
+    const STR_EMPTY = '';
     const STR_ONE_SPACE = ' ';
     const STR_ONE_INDENT = '    ';
     const STR_DIV = 'div';
     const STR_SPAN = 'span';
     const STR_BORDER = 'border';
+    const STR_BORDER_LEFT = 'border-left';
     const STR_TOP = 'top';
     const STR_LEFT = 'left';
     const STR_RIGHT = 'right';
@@ -281,6 +257,10 @@ define([
     const STR_PARENT = 'parent';
     const STR_DISABLED = 'disabled';
 
+    const STR_GRP_DEFINE = 'Define';
+    const STR_GRP_CONTROL = 'Control';
+    const STR_GRP_EXECUTE = 'Execute';
+
     const STR_CLASS = 'class';
     const STR_DEF = 'def';
     const STR_IF = 'if';
@@ -296,9 +276,13 @@ define([
     const STR_CONTINUE = 'continue';
     const STR_PASS = 'pass';
     const STR_CODE = 'code';
+    const STR_COMMENT = 'comment';
+    const STR_NODE = 'node';
+    const STR_TEXT = 'text';
+    const STR_PRINT = 'print';
     const STR_ELIF = 'elif';
     const STR_ELSE = 'else';
-    const STR_PROPERTY = 'property';
+    const STR_PROPERTY = 'decoration';
     const STR_LAMBDA = 'lambda';
 
     const STR_TITLE = 'title';
@@ -328,7 +312,7 @@ define([
     const STR_BORDER_BOTTOM_LEFT_RADIUS = 'border-bottom-left-radius';
     const STR_BORDER_TOP_RIGHT_RADIUS = 'border-top-right-radius';
     const STR_BORDER_BOTTOM_RIGHT_RADIUS = 'border-bottom-right-radius';
-
+ 
     const STR_3PX = '3px';
     const STR_100PERCENT = '100%';
     const STR_SOLID = 'solid';
@@ -349,13 +333,20 @@ define([
     const STR_VALUE = 'Value';
     const STR_METHOD = 'Method';
 
+    const STR_UNTITLED = 'Untitled';
+    const STR_TEXT_BLOCK_MARKDOWN_FUNCID = 'com_markdown';
+    const STR_SAMPLE_TEXT = 'Sample Text';
+
     /** ---------------------------------------- const CSS id String ------------------------------------------ */
     const VP_ID_PREFIX = '#';
+    const VP_ID_WRAPPER = 'vp-wrapper';
     const VP_ID_APIBLOCK_VIEWDEPTH = 'vp_apiblock_viewdepth';
     const VP_ID_APIBLOCK_LINENUMBER_ASC = 'vp_apiblock_linenumberasc';
     const VP_ID_APIBLOCK_DELETE_BLOCK_ALL = 'vp_apiblock_deleteblockall';
     const VP_ID_APIBLOCK_CLOSE = 'vp_apiblock_close';
+    const VP_ID_APIBLOCK_LEFT_TAB_API = 'vp_apiblock_left_tab_api';
 
+    const VP_ID_APIBLOCK_OPTION_CODE_ARG = 'vp_apiblockCodeOptionInput';
 
     const VP_ID_APIBLOCK_OPTION_DEF_ARG_3 = 'vp_ApiblockDefArg3';
     const VP_ID_APIBLOCK_OPTION_DEF_ARG_4 = 'vp_ApiblockDefArg4';
@@ -411,14 +402,34 @@ define([
     const VP_ID_APIBLOCK_OPTION_LAMBDA_ARG_3 = 'vp_apiblockOptionLambdaArg3';
     const VP_ID_APIBLOCK_OPTION_LAMBDA_ARG_4 = 'vp_apiblockOptionLambdaArg4';
 
+    const VP_ID_APIBLOCK_OPTION_WHILE_TYPE_SELECT = 'vp_apiblockOptionWhileTypeSelect';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG  = 'vp_apiblockOptionWhileArg';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_1 = 'vp_apiblockOptionWhileArg1';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_2 = 'vp_apiblockOptionWhileArg2';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_3 = 'vp_apiblockOptionWhileArg3';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_4 = 'vp_apiblockOptionWhileArg4';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_5 = 'vp_apiblockOptionWhileArg5';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_6 = 'vp_apiblockOptionWhileArg6';
+    const VP_ID_APIBLOCK_OPTION_WHILE_ARG_7 = 'vp_apiblockOptionWhileArg7';
+    const VP_ID_APIBLOCK_OPTION_WHILE_PLUS = 'vp_apiblockOptionPlusWhile';
+    const VP_ID_APIBLOCK_OPTION_WHILE_DELETE = 'vp_apiblockOptionDeleteWhile';
+
+    const VP_ID_APIBLOCK_LEFT_TAP_APILIST_PAGE = 'vp_apiblock_left_tab_api';
+    const VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON = 'vp_apiblock_board_node_plus_button';
+    const VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON = 'vp_apiblock_board_text_plus_button';
+    const VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT = 'vp_apiblock_board_makenode_input';
+
     /** ---------------------------------------- const CSS class String ------------------------------------------ */
     const VP_CLASS_PREFIX = '.';
     
     const VP_BLOCK = 'vp-block';
     const VP_CLASS_BLOCK_CONTAINER = 'vp-block-container';
 
+    const VP_CLASS_BLOCK_GROUPBOX_PREFIX = 'vp-block-group-box-';
+
     const VP_BLOCK_BLOCKCODELINETYPE_CLASS_DEF = 'vp-block-class-def';
     const VP_BLOCK_BLOCKCODELINETYPE_CONTROL = 'vp-block-control';
+    const VP_BLOCK_BLOCKCODELINETYPE_API = 'vp-block-api';
     const VP_BLOCK_BLOCKCODELINETYPE_CODE = 'vp-block-blockcodelinetype-code';
     const VP_CLASS_BLOCK_NUM_INFO = 'vp-block-num-info';
     const VP_CLASS_APIBLOCK_MINIMIZE = 'vp-apiblock-minimize';
@@ -433,18 +444,22 @@ define([
     const VP_CLASS_BLOCK_SHADOWBLOCK = 'vp-block-shadowblock';
     const VP_CLASS_BLOCK_OPTION_BTN = 'vp-block-option-btn';
     const VP_CLASS_BLOCK_DELETE_BTN = 'vp-block-delete-btn';
+    const VP_CLASS_BLOCK_SUB_BTN_CONTAINER = 'vp-apiblock-block-container-button';
     const VP_CLASS_BLOCK_LEFT_HOLDER = 'vp-block-left-holder';
     const VP_CLASS_BLOCK_DEPTH_INFO = 'vp-block-depth-info';
     const VP_CLASS_BLOCK_CTRLCLICK_INFO = 'vp-block-ctrlclick-info';
+    const VP_CLASS_APIBLOCK_BLOCK_HEADER = 'vp-block-header-';
     const VP_CLASS_APIBLOCK_TAB_NAVIGATION_NODE_OPTION_TITLE_SAPN = 'vp-apiblock-tab-navigation-node-option-title span';
     const VP_CLASS_APIBLOCK_TAB_NAVIGATION_NODE_OPTION_CHILDS_TOP_TITLE_SAPN ='vp-apiblock-tab-navigation-node-childs-top-option-title span'
     const VP_CLASS_APIBLOCK_BODY = 'vp-apiblock-body';
     const VP_CLASS_APIBLOCK_MAIN = 'vp-apiblock-main';
-    const VP_CLASS_APIBLOCK_BOARD = 'vp-apiblock-left';
-    const VP_CLASS_APIBLOCK_BUTTONS = 'vp-apiblock-right';
+    const VP_CLASS_APIBLOCK_BOARD_CONTAINER = 'vp-apiblock-right';
+    const VP_CLASS_APIBLOCK_BOARD = 'vp-apiblock-board-body';
+    const VP_CLASS_APIBLOCK_BUTTONS = 'vp-apiblock-left';
     const VP_CLASS_APIBLOCK_OPTION_TAB = 'vp-apiblock-option-tab';
     const VP_CLASS_APIBLOCK_OPTION_TAB_CHILDS_OPTION = 'vp-apiblock-option-tab-childs-option';
-    const VP_CLASS_APIBLOCK_BOTTOM_TAB_VIEW = 'vp-apiblock-bottom-tab-view';
+    const VP_CLASS_APIBLOCK_OPTION_NAME = 'vp-apiblock-optionpage-name';
+    const VP_CLASS_APIBLOCK_OPTION_TAB_SELECTOR = 'vp-apiblock-option-container';
     const VP_CLASS_APIBLOCK_BOTTOM_OPTIONAL_TAB_VIEW = 'vp-apiblock-bottom-optional-tab-view';
     const VP_CLASS_APIBLOCK_SCROLLBAR = 'vp-apiblock-scrollbar';
     const VP_CLASS_APIBLOCK_CODELINE_ELLIPSIS = 'vp-apiblock-codeline-ellipsis';
@@ -463,10 +478,14 @@ define([
     const VP_CLASS_APIBLOCK_MENU_BTN = 'vp-apiblock-menu-button';
     const VP_CLASS_SELECTED_SHADOWBLOCK = 'selected-shadowblock';
 
+    const VP_CLASS_APIBLOCK_NODEBLOCK_INPUT = 'vp-apiblock-nodeblock-input';
+    const VP_CLASS_APIBLOCK_NODEBLOCK_TEXT = 'vp-apiblock-nodeblock-text';
+    const VP_CLASS_APIBLOCK_NODEBLOCK_TEXT_CONTAINER = 'vp-apiblock-nodeblock-text-container';
+    const VP_CLASS_APIBLOCK_NODEBLOCK = 'vp-apiblock-nodeblock';
+
     /** const Option  */
     const VP_CLASS_APIBLOCK_OPTION_INPUT = 'vp-apiblock-option-input';
 
-    const VP_ID_APIBLOCK_OPTION_CODE_ARG = 'vp_apiblockCodeOptionInput';
 
     /** const Css Style */
     const VP_CLASS_STYLE_FLEX_ROW = 'vp-apiblock-style-flex-row';
@@ -513,6 +532,9 @@ define([
     const VP_CLASS_STYLE_MARGIN_LEFT_10PX = 'vp-apiblock-style-margin-left-10px';
     const VP_CLASS_STYLE_MARGIN_LEFT_15PX = 'vp-apiblock-style-margin-left-15px';
 
+    const VP_CLASS_STYLE_DISPLAY_BLOCK = 'vp-apiblock-style-display-block';
+    const VP_CLASS_STYLE_DISPLAY_NONE = 'vp-apiblock-style-display-none';
+    const VP_CLASS_STYLE_DISPLAY_FLEX = 'vp-apiblock-style-display-flex';
 
     /** ---------------------------------------- const Message String --------------------------------------------- */
     const STR_MSG_BLOCK_DELETED = 'Block deleted!';
@@ -530,7 +552,7 @@ define([
     const PNG_VP_APIBLOCK_DELETE_ICON = 'vp-apiblock-delete-icon.png';
 
     /** ---------------------------------------- const State Name String ------------------------------------------ */
-    const STATE_optionState = 'optionState';
+    const STATE_state = 'state';
 
     /** Class */
     const STATE_classInParamList = 'classInParamList';
@@ -541,25 +563,20 @@ define([
     const STATE_defName = 'defName';
     const STATE_defInParamList = 'defInParamList';
     const STATE_defReturnType = 'defReturnType';
+
     /** If */
-    const STATE_ifCodeLine = 'ifCodeLine';
     const STATE_isIfElse = 'isIfElse';
     const STATE_isForElse = 'isForElse';
     const STATE_ifConditionList = 'ifConditionList';
     const STATE_elifConditionList = 'elifConditionList';
-    const STATE_elifCodeLine = 'elifCodeLine';
-    const STATE_elifList = 'elifList';
-    
-    /** For */
-    const STATE_forCodeLine = 'forCodeLine';
     const STATE_forParam = 'forParam';
-    const STATE_forBlockOptionType = 'forBlockOptionType';
-    const STATE_listforConditionList = 'listforConditionList';
-    const STATE_listforReturnVar = 'listforReturnVar';
-    const STATE_listforPrevExpression = 'listforPrevExpression';
+
+
+    /** For */
 
     /** While */
-    const STATE_whileCodeLine = 'whileCodeLine';
+    const STATE_whileBlockOptionType = 'whileBlockOptionType';
+    const STATE_whileConditionList = 'whileConditionList';
 
     /** Import */
     const STATE_baseImportList = 'baseImportList';
@@ -567,8 +584,6 @@ define([
     const STATE_isBaseImportPage = 'isBaseImportPage';
 
     /** Except */
-    const STATE_exceptList = 'exceptList';
-    const STATE_exceptCodeLine = 'exceptCodeLine';
     const STATE_exceptConditionList = 'exceptConditionList';
 
     /** Finally */
@@ -578,29 +593,24 @@ define([
     const STATE_returnOutParamList = 'returnOutParamList';
     
     /** Code */
-    const STATE_customCodeLine = 'customCodeLine';
-    const STATE_breakCodeLine = 'breakCodeLine';
-    const STATE_continueCodeLine = 'continueCodeLine';
-    const STATE_passCodeLine = 'passCodeLine';
-    const STATE_propertyCodeLine = 'propertyCodeLine';
-    const STATE_commentLine = 'commentLine';
+    const STATE_codeLine = 'customCodeLine';
 
     /** Lambda */
     const STATE_lambdaArg1 = 'lambdaArg1';
     const STATE_lambdaArg2List = 'lambdaArg2List';
-    const STATE_lambdaArg2m_List = 'lambdaArg2m_List';
     const STATE_lambdaArg3 = 'lambdaArg3';
-    const STATE_lambdaArg4List = 'lambdaArg4List';
 
 
     /** ---------------------------------------- const Color String ------------------------------------------ */
-  
-    const COLOR_CLASS_DEF = 'rgba(47, 133, 90, 0.2)';
-    const COLOR_CONTROL = 'rgba(246, 173, 85, 0.2)';
+
+    const COLOR_CLASS_DEF = 'rgb(213, 231, 222)';
+    const COLOR_CONTROL = 'rgb(253, 239, 221)';
+    const COLOR_API = '#F9E3D6'; //'rgb(255, 165, 113)';
     const COLOR_CODE = '#E5E5E5';
 
     const COLOR_CLASS_DEF_STRONG = '#8AD6B0';
     const COLOR_CONTROL_STRONG = '#FFCF73';
+    const COLOR_API_STRONG = '#fdb185';
     const COLOR_CODE_STRONG = '#C4C4C4';
 
     const COLOR_YELLOW = 'yellow';
@@ -609,6 +619,7 @@ define([
     const COLOR_GRAY_input_your_code = '#d4d4d4';
     const COLOR_FOCUSED_PAGE = '#66BB6A';
     const COLOR_BLACK = '#696969';
+    const COLOR_LINENUMBER = '#E5E5E5';
     const COLOR_LIST = ["rgb(47, 133, 90)", "rgb(246, 173, 85)", "#E5E5E5", "yellow", "#6E5261", "#D3E9FF", "#FFD5D5", "#FFA0AD", "#509BE1", "#FF71B2"];
 
     /** ---------------------------------------- const Error String ------------------------------------------ */
@@ -622,26 +633,94 @@ define([
 
     /** ---------------------------------------- const operator ---------------------------------------------- */
     const COMPARISON_OPERATOR = ['==' ,'!=', '<', '>', '>=', '<='];
-    const COMPARISON_OPERATOR_IF_ARG2 = ['==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in', '+',  '-', '*', '/', '%'];
-    const COMPARISON_OPERATOR_IF_ARG4 = ['none', '==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
+    const COMPARISON_OPERATOR_IF_ARG2 = ['', '==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in', '+',  '-', '*', '/', '%'];
+    const COMPARISON_OPERATOR_IF_ARG4 = ['', '==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
     const COMPARISON_OPERATOR_IF_ARG6 = ['==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
-    const COMPARISON_OPERATOR_FOR = [];
     
     const DEF_PARAM_TYPE_LIST = ['int','str','float','bool','complex','bytes','tuple','list','dict'];
+
+    const WHILE_OPERATOR_ARG1 = ['True','False'];
+    const WHILE_OPERATOR_ARG2 = ['==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
+
+    const IMPORT_DEFAULT_DATA_LIST = [
+        {
+            isImport: false
+            , baseImportName: 'numpy' 
+            , baseAcronyms: 'np' 
+        }   
+        , {
+            isImport: false
+            , baseImportName: 'pandas' 
+            , baseAcronyms: 'pd' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'matplotlib.pyplot' 
+            , baseAcronyms: 'plt' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'seaborn' 
+            , baseAcronyms: 'sns' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'os' 
+            , baseAcronyms: 'os' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'sys' 
+            , baseAcronyms: 'sys' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'time' 
+            , baseAcronyms: 'time' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'datetime' 
+            , baseAcronyms: 'datetime' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'random' 
+            , baseAcronyms: 'random' 
+        }
+        , {
+            isImport: false
+            , baseImportName: 'math' 
+            , baseAcronyms: 'math' 
+        }
+    ]
+
+    const IMPORT_LIBRARY_LIST = {
+        0: { value: 'numpy', text: 'numpy' }
+        , 1: { value: 'pandas', text: 'pandas' }
+        , 2: { value: 'matplotlib', text: 'matplotlib' }
+        , 3: { value: 'seaborn', text: 'seaborn'}
+        , 4: { value: 'os', text: 'os'}
+        , 5: { value: 'sys', text: 'sys'}
+        , 6: { value: 'time', text: 'time'}
+        , 7: { value: 'datetime', text: 'datetime'}
+        , 8: { value: 'random', text: 'random'}
+        , 9: { value: 'math', text: 'math'}
+    }
+    // const WHILE_OPERATOR_ARG4 = ['none', '==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
+    // const WHILE_OPERATOR_ARG6 = ['==' ,'!=', '<', '>', '>=', '<=', 'and', 'or', 'in','not in'];
+
     return {
-        BLOCK_CODELINE_BTN_TYPE
+        BLOCK_GROUP_TYPE
+        , BLOCK_CODELINE_BTN_TYPE
         , BLOCK_CODELINE_TYPE
         , BLOCK_DIRECTION
-        , BLOCK_TYPE
-        , MAKE_CHILD_BLOCK
         , IMPORT_BLOCK_TYPE
         , FOCUSED_PAGE_TYPE
 
         , DEF_BLOCK_TYPE
-        , DEF_BLOCK_PARAM_TYPE // 임시
+        , DEF_BLOCK_PARAM_TYPE
 
-        , DEF_BLOCK_ARG4_TYPE
-        , DEF_BLOCK_ARG4_TYPE_EXCEPT_INPUT_STR
         , DEF_BLOCK_ARG6_TYPE
         , DEF_BLOCK_SELECT_VALUE_ARG_TYPE
 
@@ -654,6 +733,10 @@ define([
 
         , LAMBDA_BLOCK_SELECT_VALUE_ARG_TYPE
 
+        , WHILE_BLOCK_SELECT_VALUE_ARG_TYPE
+        , WHILE_OPERATOR_ARG1
+        , WHILE_OPERATOR_ARG2
+
         , NUM_INDENT_DEPTH_PX
         , NUM_BLOCK_HEIGHT_PX
         , NUM_MAX_ITERATION
@@ -663,6 +746,8 @@ define([
         , NUM_HUNDREAD
         , NUM_THOUSAND
         , NUM_DELETE_KEY_EVENT_NUMBER 
+        , NUM_ENTER_KEY_EVENT_NUMBER
+        
         , NUM_DEFAULT_POS_X
         , NUM_DEFAULT_POS_Y
         , NUM_DEFAULT_BLOCK_LEFT_HOLDER_HEIGHT
@@ -675,8 +760,15 @@ define([
         , NUM_FONT_WEIGHT_300
         , NUM_FONT_WEIGHT_700
         , NUM_MAX_BLOCK_NUMBER
+        , NUM_NODE_OR_TEXT_BLOCK_MARGIN_TOP_PX
         , NUM_BLOCK_MAX_WIDTH
+        , NUM_APIBLOCK_MAIN_PAGE_WIDTH
+        , NUM_APIBLOCK_LEFT_PAGE_WIDTH
         , NUM_OPTION_PAGE_WIDTH
+        , NUM_BUTTONS_PAGE_WIDTH
+        , NUM_API_BOARD_CENTER_PAGE_WIDTH
+        , NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH
+        , NUM_TEXT_BLOCK_WIDTH
 
         , STR_TOP
         , STR_LEFT
@@ -684,6 +776,7 @@ define([
         , STR_DIV
         , STR_SPAN
         , STR_BORDER
+        , STR_BORDER_LEFT
         , STR_PX
         , STR_OPACITY
         , STR_MARGIN_TOP
@@ -692,7 +785,6 @@ define([
         , STR_DISPLAY
         , STR_BACKGROUND_COLOR
         , STR_WIDTH
-        , STR_MIN_WIDTH
         , STR_HEIGHT
         , STR_INHERIT
         , STR_YES
@@ -718,6 +810,10 @@ define([
         , STR_CHECKED
         , STR_SCROLL
 
+        , STR_GRP_DEFINE
+        , STR_GRP_CONTROL
+        , STR_GRP_EXECUTE
+
         , STR_CLASS
         , STR_DEF
         , STR_IF
@@ -733,6 +829,10 @@ define([
         , STR_CONTINUE
         , STR_PASS
         , STR_CODE
+        , STR_COMMENT
+        , STR_NODE
+        , STR_TEXT
+        , STR_PRINT
         , STR_ELIF
         , STR_ELSE
         , STR_PROPERTY
@@ -755,9 +855,11 @@ define([
 
         , STR_FONT_WEIGHT
         , STR_MAX_WIDTH
+        , STR_MIN_WIDTH
         , STR_STRONG
         , STR_FLEX
         
+        , STR_MARGIN_TOP
         , STR_BORDER_RIGHT
         , STR_BORDER_TOP_LEFT_RADIUS
         , STR_BORDER_BOTTOM_LEFT_RADIUS
@@ -772,7 +874,7 @@ define([
         , STR_CELL
         , STR_CODEMIRROR_LINES
 
-        , STR_NULL
+        , STR_EMPTY
         , STR_DOT
         , STR_KEYWORD_NEW_LINE
         , STR_ONE_SPACE
@@ -786,16 +888,21 @@ define([
         , STR_VALUE
         , STR_METHOD
 
+        , STR_UNTITLED
+
         , VP_BLOCK
         , VP_BLOCK_BLOCKCODELINETYPE_CLASS_DEF
         , VP_BLOCK_BLOCKCODELINETYPE_CONTROL
+        , VP_BLOCK_BLOCKCODELINETYPE_API
         , VP_BLOCK_BLOCKCODELINETYPE_CODE
         
         , VP_ID_PREFIX
+        , VP_ID_WRAPPER
         , VP_ID_APIBLOCK_VIEWDEPTH
         , VP_ID_APIBLOCK_LINENUMBER_ASC
         , VP_ID_APIBLOCK_DELETE_BLOCK_ALL
         , VP_ID_APIBLOCK_CLOSE
+        , VP_ID_APIBLOCK_LEFT_TAB_API
 
         , VP_ID_APIBLOCK_OPTION_CODE_ARG
 
@@ -851,8 +958,27 @@ define([
         , VP_ID_APIBLOCK_OPTION_LAMBDA_ARG_3
         , VP_ID_APIBLOCK_OPTION_LAMBDA_ARG_4
         
+        , VP_ID_APIBLOCK_OPTION_WHILE_TYPE_SELECT
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG 
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_1
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_2
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_3
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_4
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_5
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_6
+        , VP_ID_APIBLOCK_OPTION_WHILE_ARG_7
+        , VP_ID_APIBLOCK_OPTION_WHILE_PLUS
+        , VP_ID_APIBLOCK_OPTION_WHILE_DELETE
+
+        , VP_ID_APIBLOCK_LEFT_TAP_APILIST_PAGE
+        , VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON
+        , VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON
+        , VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT
+
         , VP_CLASS_PREFIX
 
+        , VP_CLASS_BLOCK_GROUPBOX_PREFIX
+
         , VP_CLASS_BLOCK_CODETYPE_NAME
         , VP_CLASS_BLOCK_CONTAINER
         , VP_CLASS_BLOCK_SHADOWBLOCK_CONTAINER
@@ -861,6 +987,7 @@ define([
         , VP_CLASS_BLOCK_SHADOWBLOCK
         , VP_CLASS_BLOCK_OPTION_BTN
         , VP_CLASS_BLOCK_DELETE_BTN
+        , VP_CLASS_BLOCK_SUB_BTN_CONTAINER
         , VP_CLASS_BLOCK_DEPTH_INFO
         , VP_CLASS_BLOCK_CTRLCLICK_INFO
         , VP_CLASS_BLOCK_LEFT_HOLDER
@@ -871,19 +998,22 @@ define([
         , VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED
         , VP_CLASS_APIBLOCK_BODY
         , VP_CLASS_APIBLOCK_MAIN
+        , VP_CLASS_APIBLOCK_BOARD_CONTAINER
         , VP_CLASS_APIBLOCK_BOARD
         , VP_CLASS_APIBLOCK_BUTTONS
         , VP_CLASS_APIBLOCK_OPTION_TAB
         , VP_CLASS_APIBLOCK_OPTION_TAB_CHILDS_OPTION
+        , VP_CLASS_APIBLOCK_OPTION_NAME
         , VP_CLASS_APIBLOCK_SCROLLBAR
         , VP_CLASS_APIBLOCK_CODELINE_ELLIPSIS
-        , VP_CLASS_APIBLOCK_BOTTOM_TAB_VIEW
+        , VP_CLASS_APIBLOCK_OPTION_TAB_SELECTOR
         , VP_CLASS_APIBLOCK_BOTTOM_OPTIONAL_TAB_VIEW
         , VP_CLASS_APIBLOCK_MINIMIZE
         , VP_CLASS_APIBLOCK_ARROW_UP
         , VP_CLASS_APIBLOCK_ARROW_DOWN
         , VP_CLASS_APIBLOCK_TAB_NAVIGATION_NODE_OPTION_TITLE_SAPN
         , VP_CLASS_APIBLOCK_TAB_NAVIGATION_NODE_OPTION_CHILDS_TOP_TITLE_SAPN
+        , VP_CLASS_APIBLOCK_BLOCK_HEADER
         , VP_CLASS_SELECTED_SHADOWBLOCK
 
         , VP_CLASS_BLOCK_HEADER_PARAM
@@ -895,7 +1025,11 @@ define([
         , VP_CLASS_APIBLOCK_TITLE
         
         , VP_CLASS_APIBLOCK_OPTION_INPUT
-
+        , VP_CLASS_APIBLOCK_NODEBLOCK_INPUT
+        , VP_CLASS_APIBLOCK_NODEBLOCK
+        , VP_CLASS_APIBLOCK_NODEBLOCK_TEXT
+        , VP_CLASS_APIBLOCK_NODEBLOCK_TEXT_CONTAINER
+        
         , VP_CLASS_STYLE_FLEX_ROW
         , VP_CLASS_STYLE_FLEX_ROW_CENTER
         , VP_CLASS_STYLE_FLEX_ROW_WRAP
@@ -940,6 +1074,10 @@ define([
         , VP_CLASS_STYLE_MARGIN_LEFT_10PX
         , VP_CLASS_STYLE_MARGIN_LEFT_15PX
         
+        , VP_CLASS_STYLE_DISPLAY_BLOCK
+        , VP_CLASS_STYLE_DISPLAY_NONE
+        , VP_CLASS_STYLE_DISPLAY_FLEX
+
         , STR_CHANGE_KEYUP_PASTE
         , STR_INPUT_YOUR_CODE
 
@@ -950,7 +1088,10 @@ define([
         , STR_ICON_ARROW_UP
         , STR_ICON_ARROW_DOWN
 
-        , STATE_optionState
+        , STR_TEXT_BLOCK_MARKDOWN_FUNCID
+        , STR_SAMPLE_TEXT
+        
+        , STATE_state
 
         , STATE_classInParamList
         , STATE_className
@@ -960,53 +1101,38 @@ define([
         , STATE_defInParamList
         , STATE_defReturnType
 
-        , STATE_ifCodeLine
         , STATE_ifConditionList
         , STATE_elifConditionList
 
         , STATE_isIfElse
         , STATE_isForElse
-
-        , STATE_elifCodeLine
-        , STATE_elifList
-
-        , STATE_forCodeLine
         , STATE_forParam
-        , STATE_forBlockOptionType
-        , STATE_listforConditionList
-        , STATE_listforReturnVar
-        , STATE_listforPrevExpression
 
-        , STATE_whileCodeLine
+        , STATE_whileBlockOptionType
+        , STATE_whileConditionList
+
         , STATE_baseImportList
         , STATE_customImportList
         , STATE_isBaseImportPage
 
-        , STATE_exceptList
-        , STATE_exceptCodeLine
         , STATE_exceptConditionList
         
         , STATE_isFinally
         , STATE_returnOutParamList
-        , STATE_customCodeLine
-        , STATE_breakCodeLine
-        , STATE_continueCodeLine
-        , STATE_passCodeLine
-        , STATE_propertyCodeLine
-        , STATE_commentLine
-        
+        , STATE_codeLine
+
         , STATE_lambdaArg1
         , STATE_lambdaArg2List
-        , STATE_lambdaArg2m_List
         , STATE_lambdaArg3
-        , STATE_lambdaArg4List
 
         , COLOR_CLASS_DEF
         , COLOR_CONTROL
+        , COLOR_API
         , COLOR_CODE
 
         , COLOR_CLASS_DEF_STRONG
         , COLOR_CONTROL_STRONG
+        , COLOR_API_STRONG
         , COLOR_CODE_STRONG
         
         , COLOR_YELLOW
@@ -1015,6 +1141,7 @@ define([
         , COLOR_GRAY_input_your_code
         , COLOR_FOCUSED_PAGE
         , COLOR_BLACK
+        , COLOR_LINENUMBER
         , COLOR_LIST
 
         , IMPORT_LIBRARY_LIST
@@ -1037,5 +1164,7 @@ define([
         , COMPARISON_OPERATOR_IF_ARG6
 
         , DEF_PARAM_TYPE_LIST
+
+        , IMPORT_DEFAULT_DATA_LIST
     }
 });
