@@ -2,6 +2,7 @@ define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
     , 'nbextensions/visualpython/src/common/constant'
+    , 'nbextensions/visualpython/src/container/vpContainer'
 
     , './api.js'    
 
@@ -13,11 +14,11 @@ define([
     , './api_list.js'
 
     , './component/boardMenuBar.js'
-], function ( $, vpCommon, vpConst, 
+], function ( $, vpCommon, vpConst, vpContainer, 
               api, constData, blockContainer, createBlockBtn, createApiBtn, createGroup, api_list,
               apiBlockMenuInit ) {
  
-    const { ControlToggleInput, LoadVariableList, MapGroupTypeToName } = api;
+    const { IsCodeBlockType, ControlToggleInput, LoadVariableList, MapGroupTypeToName } = api;
   
     const { BLOCK_GROUP_TYPE
             , BLOCK_CODELINE_BTN_TYPE
@@ -32,66 +33,51 @@ define([
             , VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON
             , VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON
             , VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT 
+            , VP_ID_APIBLOCK_DELETE_BLOCK_ALL
 
             , VP_CLASS_PREFIX
             , VP_CLASS_BLOCK_GROUPBOX_PREFIX
-            , VP_CLASS_APIBLOCK_MAIN
-            , VP_CLASS_APIBLOCK_BODY
             , VP_CLASS_APIBLOCK_BOARD_CONTAINER
-            , VP_CLASS_APIBLOCK_MENU_BTN
-            , VP_CLASS_MAIN_CONTAINER
-            , VP_CLASS_APIBLOCK_CODELINE_ELLIPSIS
-            , VP_CLASS_STYLE_DISPLAY_FLEX
 
-            , API_BLOCK_PROCESS_PRODUCTION
-            , API_BLOCK_PROCESS_DEVELOPMENT
             , VP_CLASS_APIBLOCK_BUTTONS
             , VP_CLASS_APIBLOCK_BOARD
             , VP_CLASS_APIBLOCK_OPTION_TAB
 
-
-            , VP_CLASS_STYLE_DISPLAY_BLOCK
-            , VP_CLASS_STYLE_DISPLAY_NONE
-
             , NUM_DELETE_KEY_EVENT_NUMBER
             , NUM_ENTER_KEY_EVENT_NUMBER
-            , NUM_APIBLOCK_MAIN_PAGE_WIDTH
             , NUM_APIBLOCK_LEFT_PAGE_WIDTH
-            , NUM_OPTION_PAGE_WIDTH
             , NUM_API_BOARD_CENTER_PAGE_WIDTH
 
-            , STR_TOP
-            , STR_SCROLL
             , STR_CLICK
             , STR_EMPTY
             , STR_WIDTH 
             , STR_MAX_WIDTH
-
-            , STR_DISPLAY
-       
-            , STR_BLOCK
             , STR_PARENT
             , STR_NONE
             , STR_NOTEBOOK
             , STR_HEADER
             , STR_CELL
             , STR_CODEMIRROR_LINES
-
-            , STATE_codeLine } = constData;
+            , STR_UNTITLED } = constData;
 
     const BlockContainer = blockContainer;
     const CreateBlockBtn = createBlockBtn;
     const CreateApiBtn = createApiBtn;
     const CreateGroup = createGroup;
-    const { api_listInit 
-            , libraryLoadCallback
-            , toggleApiListSubGroupShow
-            , makeOptionPageNaviInfo
+    
+    const { toggleApiListSubGroupShow
             , loadLibraries
             , loadLibrariesToJson
             , getNavigationInfo } = api_list;
 
-    var init = function(){
+    const { saveAsNotePage
+            , openNotePage
+            , closeNoteExtraMenu
+            , saveNotePageAction_newVersion
+            , openNotePageAction_newVersion } = vpContainer;
+            
+
+    var init = function(apiBlockPackage){
         /** 제이쿼리 커스텀 메소드 생성
          *  싱글 클릭 혹은 더블 클릭 바인딩
          * 
@@ -121,6 +107,7 @@ define([
          * 싱글톤 무조건 1개
          */
         var blockContainer = new BlockContainer();
+        blockContainer.setImportPackageThis(apiBlockPackage);
 
         /** Logic에 블럭 그룹 생성 */
         var createLogicGroupArray = Object.values(BLOCK_GROUP_TYPE);
@@ -171,32 +158,34 @@ define([
         var buttonsPageRectWidth = NUM_APIBLOCK_LEFT_PAGE_WIDTH; 
         /** 가운데 board 영역의 width */
         var boardPageRectWidth = NUM_API_BOARD_CENTER_PAGE_WIDTH;
-        // blockContainer.resizeAPIblock();
         /** 오른쪽 option 영역의 width 계산 */
         var optionPageRectWidth = mainPageRectWidthNum - buttonsPageRectWidth - boardPageRectWidth - 103;
 
-        blockContainer.setOptionPageWidth(optionPageRectWidth); 
-
+        /** visual python 전체의 width 렌더링 */
         $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_WRAPPER)).css(STR_WIDTH, mainPageRectWidth);
-        $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_WIDTH, optionPageRectWidth);
+        /** 가운데 board 영역의 width 렌더링 */
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD_CONTAINER)).css(STR_WIDTH, boardPageRectWidth);
+        /** 오른쪽 option 영역의 width 렌더링*/
+        $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_WIDTH, optionPageRectWidth);
         
+        /** 오른쪽 option 영역의 max-width 렌더링*/
         var optionPageRectWidth_maxWidth = mainPageRectWidthNum - buttonsPageRectWidth - 290 - 103;
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css(STR_MAX_WIDTH, optionPageRectWidth_maxWidth);
 
-        $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val('Untitled');
+        /** 가운데 board 위 영역의 렌더링 */
+        $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val(STR_UNTITLED);
         $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).focus();
 
-        /** API List xml 데이터를 xmlLibraries에 대입 변수 */
+        /** API List 함수들을 Logic아래에 렌더링한 후에 
+         *  API List xml 데이터를 xmlLibraries변수에 대입 */
         var xmlLibraries = loadLibraries(VP_ID_PREFIX + VP_ID_APIBLOCK_LEFT_TAB_API);
 
-        /** 블럭이 생성되어 보여지는 container를 생성하고
+        /** 블럭이 생성되어 보여지는 container dom을 생성하고
          *  board에 container dom을 렌더링
          */
         blockContainer.reNewContainerDom();
         
-        /** delete 키를 누르거나,
-         *  enter키를 누를 때 keyup 이벤트 발동
+        /** delete 키 or 엔터 키를 누를 때 keyup 이벤트 발동
          */
         $(document).keyup(function(e) {
             var keycode =  e.keyCode 
@@ -209,36 +198,22 @@ define([
             /** block을 클릭하고 delete 키 눌렀을 때 */ 
             if (keycode == NUM_DELETE_KEY_EVENT_NUMBER
                 && selectedBlock){
-
                 selectedBlock.deleteBlock_childBlockList();
-
                 blockContainer.resetOptionPage();
                 blockContainer.reRenderAllBlock_asc();
             } 
 
-            /** Enter 이벤트 */
-            /** 'Untitled이라고 표시된 input 태그에 focus한 상태에서
-             *  엔터키를 누르면
-             *  input 태그에 적힌 title이름으로 node 블럭 생성
-             */
-            // if ($(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).is(":focus") 
-                // && window.event.keyCode == NUM_ENTER_KEY_EVENT_NUMBER) {
-                // var inputNodeBlockTitleName = $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val();
-                // if (inputNodeBlockTitleName == STR_EMPTY) {
-                    // vpCommon.renderAlertModal('Required input!');
-                    // $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val(STR_EMPTY);
-                    // return;
-                // }
-
-                // blockContainer.createNodeBlock(true, inputNodeBlockTitleName);
-            
-                /** node 블럭 생성 했으면
-                 *  input 태그 초기화 */
-                // $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val(STR_EMPTY);
-            // }
-
+            /** 엔터 이벤트 */
+            /** node 블럭을 클릭하고 엔터키를 눌렀을 때 */
+            if (keycode == NUM_ENTER_KEY_EVENT_NUMBER
+                && selectedBlock
+                && selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.NODE){
+                // console.log('엔터');
+                selectedBlock.renderNodeBlockInput(STR_NONE);
+            }
         });
 
+        /** Logic, API, Data Analysis 의 > 버튼 클릭 */
         $(document).on(STR_CLICK,`.vp-apiblock-panel-area-vertical-btn`, function(){
             if ($(this).hasClass(`vp-apiblock-arrow-down`)) {
                 // 펼치기
@@ -253,6 +228,7 @@ define([
             }
         });
          
+        /** Logic, API, Data Analysis 의 이름 클릭*/
         $(document).on(STR_CLICK,`.vp-block-blocktab-name`, function(){
             var $arrowBtn = $(this).prev();
             if ($($arrowBtn).hasClass(`vp-apiblock-arrow-down`)) {
@@ -275,54 +251,58 @@ define([
             $('.vp-block-group-box-' + category).toggle();
         });
 
-        const blockTab_api = $(VP_ID_PREFIX + VP_ID_APIBLOCK_LEFT_TAB_API);
-        $(blockTab_api).addClass(VP_CLASS_STYLE_DISPLAY_BLOCK);
-
-        /** api block 화면 이외에 화면을 클릭했을 때, page 포커스 해제 */
+        /** visual python 화면 이외에 화면(jupyter header 영역 , jupyter cell 영역)을 클릭했을 때, 
+         *  page 포커스 해제 
+         *  option (N/A) 처리
+         *  selected 된 블럭 해제 */
         $(vpCommon.wrapSelector(`${VP_ID_PREFIX}${STR_NOTEBOOK}, 
-                                ${VP_ID_PREFIX}${STR_HEADER}, 
-                                ${VP_CLASS_PREFIX}${STR_CELL}, 
-                                ${VP_CLASS_PREFIX}${STR_CODEMIRROR_LINES},
-                                div#notebook`)).click(function(event) {
+                                 ${VP_ID_PREFIX}${STR_HEADER}, 
+                                 ${VP_CLASS_PREFIX}${STR_CELL}, 
+                                 ${VP_CLASS_PREFIX}${STR_CODEMIRROR_LINES},
+                                 div#notebook`)).click(function(event) {
             blockContainer.resetBlockList();
             blockContainer.resetOptionPage();
-            blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.NULL);
+            blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.NULL);
         });
         
         /** Create block buttons page를 클릭했을 때 */
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BUTTONS)).click(function(event) {
-            if ($(event.target).attr('id') == undefined) {
-                blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.BUTTONS);
-            } 
+            blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.BUTTONS);
         });
 
         /** Block Board page를 클릭했을 때 */
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BOARD)).click(function(event) {
-            /** Board에서 Board page를 클릭하고 block을 클릭하지 않았을 때 */
+            /** Board에서 Board page를 클릭하고, block을 클릭하지 않았을 때 */
             if ($(event.target).attr('class')
                 && ($(event.target).attr('class').indexOf('vp-apiblock-board-body') != -1 
                     || $(event.target).attr('class').indexOf('vp-block-container') != -1 ) ) {
                 blockContainer.resetBlockList();
                 blockContainer.resetOptionPage();
-                blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.EDITOR);
+                blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.EDITOR);
             }
         });
 
         /** Block Board 위 Input 영역을 클릭했을 때 */
         $(vpCommon.wrapSelector(VP_ID_PREFIX + "vp_apiblock_board_main_title")).click(function(event) {
-            blockContainer.resetBlockList();
-            blockContainer.resetOptionPage();
-            blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.BOARD_TITLE);
+            blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.BOARD_TITLE);
+        });
+
+        /** Board Main Title에서 엔터키 눌렀을 때 */
+        $(vpCommon.wrapSelector(VP_ID_PREFIX + "vp_apiblock_board_main_title")).keyup(function(event) {
+            if (event.keyCode == NUM_ENTER_KEY_EVENT_NUMBER) {
+                blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.NULL);
+                $(this).find('input').blur();
+            }
         });
 
         /** API List를 클릭했을 때*/
         $(vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_LEFT_TAP_APILIST_PAGE)).click(function(event) {
-            blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.API_LIST_TAB);
+            blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.API_LIST_TAB);
         });
 
         /** Option page를 클릭했을 때 */
         $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).click(function(event) {
-            blockContainer.setFocusedPageTypeAndRender(FOCUSED_PAGE_TYPE.OPTION);
+            blockContainer.setFocusedPageType(FOCUSED_PAGE_TYPE.OPTION);
         });
         
         /** 블럭 복사하고 붙여넣는 기능 이벤트 바인딩 */
@@ -344,18 +324,13 @@ define([
             });
 
             $(document).keydown(function(e) {
-                /** board에 선택되지 않은 블럭이거나
+                /** board에 선택한 블럭 없거나
                 *  TEXT 블럭인 경우에 ctrl + c , ctrl + v 금지
                 */
                 var selectedBlock = blockContainer.getSelectBlock();
                 if (!selectedBlock 
                     || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.TEXT
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.LAMBDA
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.CODE
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.PRINT
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.BREAK 
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.CONTINUE
-                    || selectedBlock.getBlockType() == BLOCK_CODELINE_TYPE.PASS ) {
+                    || IsCodeBlockType(selectedBlock.getBlockType()) == true ) {
                     return;
                 }   
                 // console.log('selectedBlock',selectedBlock);
@@ -364,27 +339,20 @@ define([
                 if (ctrlDown && (e.keyCode == cKey)) {
                     blockContainer.setCtrlSaveData();
                 }
-
+              
                 /** ctrl + v */
-                if (ctrlDown && (e.keyCode == vKey)) {
-
-                    const { lastBlock, lastCopyBlocklist_cloned } = blockContainer.getCtrlSaveData();
-                    lastBlock.appendBlock(lastCopyBlocklist_cloned, BLOCK_DIRECTION.DOWN);
-                    
-                    blockContainer.reRenderAllBlock_metadata();
-                    blockContainer.setCtrlSaveData();
-
-                    vpCommon.renderSuccessMessage('Blocks copy success!');
+                if (ctrlDown && (e.keyCode == vKey) ) {
+                    blockContainer.copyCtrlSaveData();
                 }
             });
         });
 
-        /** node 블럭 생성 버튼 클릭 함수 바인딩 */
+        /** +node 블럭 생성 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON, function() {
             blockContainer.createNodeBlock(true);
         });
 
-        /** text 블럭 생성 버튼 클릭 함수 바인딩 */
+        /** +text 블럭 생성 버튼 클릭 함수 바인딩 */
         $(document).on(STR_CLICK, VP_ID_PREFIX + VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON, function() {
             blockContainer.createTextBlock();
         });
@@ -423,6 +391,86 @@ define([
                 blockContainer.setIsOptionPageResize(false);
             }
         });
+        
+        /** 햄버거 메뉴 open 클릭 */
+        $(document).on(STR_CLICK, vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_EXTRA_MENU_OPEN_NOTE)), function() {
+            var saveFileName = $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val();
+            /** 빈 string이거나 
+             *  Untitled이면 File navigation을 open */
+            if ( saveFileName == STR_EMPTY
+                 || saveFileName == STR_UNTITLED) {
+                openNotePage();
+             /** File navigation을 open하지 않고 alert창 띄움*/    
+            } else {
+                var saveFilePath = vpCommon.formatString("./{0}.{1}", saveFileName, vpConst.VP_NOTE_EXTENSION);
+                apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}.vp'`,['Yes','No', 'Cancel'], [() => {
+                    saveNotePageAction_newVersion(saveFileName, saveFilePath);
+                    openNotePage();
+
+                },() => {
+                    openNotePage();
+                    
+                },() => {
+                    
+                }]);
+            }
+        });
+
+        /** 햄버거 메뉴 save 저장 클릭 */
+        $(document).on(STR_CLICK, vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_EXTRA_MENU_SAVE_NOTE)), function() {
+            var saveFileName = $(VP_ID_PREFIX + VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT).val();
+            /** 빈 string이거나 
+             *  Untitled이면 File navigation을 open */
+            if ( saveFileName == STR_EMPTY
+                || saveFileName == STR_UNTITLED) {
+                saveAsNotePage();
+                closeNoteExtraMenu();
+            /** File navigation을 open하지 않고 alert창 띄움*/
+            } else {
+                var saveFilePath = vpCommon.formatString("./{0}.{1}", saveFileName, vpConst.VP_NOTE_EXTENSION);
+                apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}.vp'`,['Yes', 'No', 'Cancel'], [() => {
+                    saveNotePageAction_newVersion(vpCommon.formatString("{0}.{1}", saveFileName, vpConst.VP_NOTE_EXTENSION), saveFilePath);
+                },() => {
+    
+                },() => {
+                    
+                }]);
+            }
+        });
+
+        /** 햄버거 메뉴 save as 다른 이름으로 저장 클릭 이벤트 함수 */
+        $(document).on(STR_CLICK, vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_EXTRA_MENU_SAVE_AS_NOTE)), function() {
+            saveAsNotePage();
+            closeNoteExtraMenu();
+        });
+
+        /**
+         * 파일 브라우저 로드 파일 선택
+         */
+        $(document).on("fileReadSelected.fileNavigation", function(e) {
+            // 선택 파일 확장자가 노트 세이브 파일인 경우만 동작
+            if (e.path.substring(e.path.lastIndexOf(".") + 1) === vpConst.VP_NOTE_EXTENSION) {
+                openNotePageAction_newVersion();
+            }
+        });
+
+        /**
+         * 파일 브라우저 저장 파일 선택
+         */
+        $(document).on("fileSaveSelected.fileNavigation", function(e) {
+            // 선택 파일 확장자가 노트 세이브 파일인 경우만 동작
+            if (e.path.substring(e.path.lastIndexOf(".") + 1) === vpConst.VP_NOTE_EXTENSION) {
+                var selectedPath = $(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.VP_NOTE_REAL_FILE_PATH))).val();
+                var saveFileName = selectedPath.substring(selectedPath.lastIndexOf("/") + 1);
+                apiBlockPackage.openMultiBtnModal_new('Save As', `Save changes to '${saveFileName}'`,['Yes','No', 'Cancel'], [() => {
+                    saveNotePageAction_newVersion(saveFileName, selectedPath);
+                },() => {
+
+                },() => {
+
+                }]);
+            }
+        });
 
         ControlToggleInput();
         return blockContainer;
