@@ -55,6 +55,7 @@ define([
      * @param {JSON} meta 메타 데이터
      */
     var initOption = function(callback, meta) {
+        // console.log('import 화면 실행');
         vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "file_io/import.html", optionLoadCallback, callback, meta);
     }
 
@@ -133,10 +134,7 @@ define([
             //         <option value="as">as</option>
             //         <option value="import">import</option>
             //     </select>
-            var tagTr = $(`<tr><td>import</td><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${package.name.toLowerCase()}"/></td>
-            <td>
-                as
-            </td>
+            var tagTr = $(`<tr><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${package.name.toLowerCase()}"/></td>
             <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${package.variable}"/></td>
             <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
         
@@ -155,8 +153,7 @@ define([
 
         // 라이브러리 추가
         $(this.wrapSelector('#vp_addLibrary')).click(function() {
-            var tagTr = $(`<tr><td>import</td><td><input type="text" class="vp-add-library" placeholder="library name" required/></td>
-            <td>as</td>
+            var tagTr = $(`<tr><td><input type="text" class="vp-add-library" placeholder="library name" required/></td>
             <td><input type="text" class="vp-input m vp-add-alias" placeholder="alias"/></td>
             <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
 
@@ -193,31 +190,16 @@ define([
 
         var sbCode = new sb.StringBuilder();
 
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
-
         // code generate with library list
         var libraryList = $(this.wrapSelector("#vp_tblImport tr:gt(0):not(:last)"));
         for (var idx = 0; idx < libraryList.length; idx++) {
             var pacName = $(libraryList[idx]).find('.vp-add-library').val();
-            var pacType = $(libraryList[idx]).find('.vp-add-type').val();
-            var pacAlias = $(libraryList[idx]).find('.vp-add-alias').val();
+            var pacAlias = $(libraryList[idx]).find('.vp-add-alias').val().trim();
 
-            // if (pacName == "" || (pacType == "import" && pacAlias == "")) {
-            //     vpCommon.renderAlertModal('빈 라이브러리 입력칸을 채우거나 삭제하세요');
-            //     return "BREAK_RUN";
-            // }
-
-            // if (pacType == 'as') {
-                // import ~ as ~
-                sbCode.appendFormatLine("import {0}{1}", pacName, ((pacAlias === undefined || pacAlias === "") ? "" : (" as " + pacAlias)));
-            // } else {
-            //     // from ~ import ~
-            //     sbCode.appendFormatLine("from {0} import {1}", pacName, pacAlias);
-            // }
+            if (pacName == "") {
+                continue;
+            }
+            sbCode.appendFormatLine("import {0}{1}", pacName, ((pacAlias === undefined || pacAlias === "") ? "" : (" as " + pacAlias)));
 
             this.packageList.forEach(pack => {
                 if (pack.name == pacName) {
@@ -231,13 +213,6 @@ define([
             })
         }
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
-
         if (addCell) {
             this.cellExecute(sbCode.toString(), exec);
         }
