@@ -94,7 +94,8 @@ define([
      */
     OptionPackage.prototype.initHtml = function() {
         var that = this;
-
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "file_io/udf.css");
+        
         // bind values after loading html
         this.package.input && this.package.input.forEach(obj => {
             if (obj.value != undefined) {
@@ -136,9 +137,75 @@ define([
             that.loadUdfList();
             // show success message
             vpCommon.renderSuccessMessage('Refreshed!');
-        })
+        });
+
+        // new button clicked
+        $(this.wrapSelector('#vp_udfCreate')).click(function() {
+            that.vp_userCode.save();
+            var code = that.vp_userCode.getValue();
+
+            if (code && code.length > 0) {
+                // ask clearing codes
+                that.openMultiBtnModal_new("Save Code", "Would you like to save previous code and clear it?"
+                , ["Just Clear", "Cancel", "Save and Clear"]
+                , [()=> {
+                    // clear code
+                    $(that.wrapSelector('#vp_udfTitle')).val('');
+                    $(that.wrapSelector('#vp_userCode')).val('');
+                    that.vp_userCode.setValue('');
+                }, ()=> {
+
+                }, ()=> {
+                    // save and clear code
+                    // save
+                    var key = $(that.wrapSelector('#vp_udfTitle')).val();
+                    if (key == undefined || key === "") {
+                        key = '_temporary';
+                    }
+
+                    // save codemirror value to origin textarea
+                    that.vp_userCode.save();
+                    var code = that.vp_userCode.getValue();
+
+                    // save udf
+                    var saveUdf = { [key]: code };
+                    vpSetting.saveUserDefinedCode(saveUdf);
+
+                    // clear code
+                    $(that.wrapSelector('#vp_udfTitle')).val('');
+                    $(that.wrapSelector('#vp_userCode')).val('');
+                    that.vp_userCode.setValue('');
+
+                    // load again
+                    that.loadUdfList();
+                }]);
+            } else {
+                // clear code
+                $(that.wrapSelector('#vp_udfTitle')).val('');
+                $(that.wrapSelector('#vp_userCode')).val('');
+                that.vp_userCode.setValue('');
+            }
+        });
+
+        // delete button clicked
+        $(this.wrapSelector('#vp_udfDelete')).click(function() {
+            // remove key from list
+            var key = $(that.wrapSelector('#vp_udfList')).find('.vp-udf-check:checked').val();
+            if (key && vpSetting.getUserDefinedCode(key)) {
+                // remove key
+                vpSetting.removeUserDefinedCode(key);
+
+                // FIXME: vp-multilang for success message
+                vpCommon.renderSuccessMessage('Successfully removed!');
+            } else {
+                vpCommon.renderAlertModal('No key available...');
+            }
+            
+            // load again
+            that.loadUdfList();
+        }); 
+        
         
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "file_io/udf.css");
     }
 
     OptionPackage.prototype.loadUdfList = function() {
@@ -149,32 +216,30 @@ define([
 
         // load udf list to table 'vp_udfList'
         vpSetting.loadUserDefinedCodeList(function(udfList) {
-            // console.log('udfList', udfList);
-
-            // TEST: test list
-            // udfList= [ {name: 'test1', code: 'codecode long code here hahahahahahahahaha example test one two three'}];
     
             udfList.forEach(obj => {
                 if (obj.code != null && obj.code != undefined) {
                     var trow = $(`<tr></tr>`);
-                    var tdTitle = $(`<td class="vp-udf-key">${obj.name}</td>`);
+                    var tdTitle = $(`<td class="vp-udf-key"><label><input type="checkbox" class="vp-udf-check" value="${obj.name}"/><span>${obj.name}</span></label></td>`);
                     var tdCode = $(`<td class="vp-udf-code"><pre title="${obj.code}">${obj.code}</pre></td>`);
                     // var tdDelete = $(`<td><button type="button" data-key="${obj.name}">X</button></td>`);
-                    var tdDelete = $(`<td><div class="vp-del-col" data-key="${obj.name}"></div></td>`);
+                    // var tdDelete = $(`<td><div class="vp-del-col" data-key="${obj.name}"></div></td>`);
         
                     // click title to load code on udf textarea
-                    tdTitle.click(function() {
-                        var key = $(this).text();
+                    trow.click(function() {
+                        var key = $(this).find('.vp-udf-check').val();
                         if (key == undefined || key === "") {
                             // 키가 존재하지 않습니다.
                             vpCommon.renderAlertModal('The key is not available now.');
                             return;
                         }
                         // 선택 표시
-                        $(this).closest('table').find('.vp-udf-key').removeClass('selected');
-                        $(this).addClass('selected');
+                        // $(this).closest('table').find('.vp-udf-key').removeClass('selected');
+                        $(this).closest('table').find('.vp-udf-check').prop('checked', false)
+                        // $(this).addClass('selected');
+                        $(this).find('.vp-udf-check').prop('checked', true);
 
-                        var code = $(this).closest('tr').find('.vp-udf-code pre').text();
+                        var code = $(this).find('.vp-udf-code pre').text();
 
                         // load code on udf textarea
                         // key title
@@ -185,28 +250,8 @@ define([
 
                     });
         
-                    // click x to remove udf from list
-                    tdDelete.click(function() {
-                        // remove key from list
-                        var key = $(this).closest('tr').find('.vp-udf-key').text();
-                        if (key != undefined
-                            && vpSetting.getUserDefinedCode(key) != undefined) {
-                            // remove key
-                            vpSetting.removeUserDefinedCode(key);
-        
-                            // FIXME: vp-multilang for success message
-                            vpCommon.renderSuccessMessage('Successfully removed!');
-                        } else {
-                            vpCommon.renderAlertModal('No key available...');
-                        }
-                        
-                        // load again
-                        that.loadUdfList();
-                    });
-        
                     trow.append(tdTitle);
                     trow.append(tdCode);
-                    trow.append(tdDelete);
         
                     $(that.wrapSelector('#vp_udfList')).append(trow);
                 }
