@@ -124,8 +124,6 @@ define([
         var sbPageContent = new sb.StringBuilder();
         var sbTagString = new sb.StringBuilder();
 
-        // prefix code 입력 영역
-        sbPageContent.appendLine(this.createPrefixCode());
 
         // Popup Box. variable view box
         sbTagString.clear();
@@ -328,9 +326,7 @@ define([
         sbPageContent.appendLine(accBoxAdditional.toTagString());
 
 
-        // postfix code 입력 영역
-        sbPageContent.appendLine(this.createPostfixCode());
-
+        
         this.setPage(sbPageContent.toString());
 
         
@@ -985,12 +981,6 @@ define([
         try {
             var sbCode = new sb.StringBuilder();
 
-            // add prefix code
-            var prefixCode = this.getPrefixCode();
-            if (prefixCode.length > 0) {
-                sbCode.appendLine(prefixCode);
-            }
-
             // 대상 변수가 입력되어 있지 않으면 plot(plt) 포커스에 차트 그리기
             // var i0Input = $(this.wrapSelector('#i0_input')).val();
             // var usePlotFunction = (i0Input == ''); // 대상 변수로 plt 를 사용할지 여부
@@ -1052,13 +1042,6 @@ define([
             sbCode.appendLine();
             sbCode.append('plt.show()');
 
-            // add postfix code
-            var postfix = this.getPostfixCode();
-            if (postfix.length > 0) {
-                sbCode.appendLine('');
-                sbCode.append(postfix);
-            }
-
             // 코드 추가 및 실행
             if (addCell) {
                 this.cellExecute(sbCode.toString(), exec);
