@@ -172,23 +172,12 @@ define([
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
 
         // 코드 생성
         var result = pdGen.vp_codeGenerator(this.uuid, this.package);
         if (result == null) return "BREAK_RUN"; // 코드 생성 중 오류 발생
         sbCode.append(result);
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
