@@ -122,11 +122,6 @@ define([
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
         
         // 코드 생성
         var result = pdGen.vp_codeGenerator(this.uuid, this.package);
@@ -136,12 +131,6 @@ define([
         // cell metadata 작성하기
         // pdGen.vp_setCellMetadata(_VP_CODEMD);
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
