@@ -118,10 +118,7 @@ define([
         var sbPageContent = new sb.StringBuilder();
         var sbTagString = new sb.StringBuilder();
 
-        // prefix code 입력 영역
-        sbPageContent.appendLine(this.createPrefixCode());
-        // sbPageContent.appendLine(this.createManualCode(vpConst.API_OPTION_PREFIX_CAPTION, vpConst.API_OPTION_PREFIX_CODE_ID, vpConst.PREFIX_CODE_SIGNATURE));
-        // this.getPrefixCode(); this.setPrefixCode("value"); // prefix code 접근
+        
 
         // 필수 옵션 테이블 레이아웃
         var tblLayoutRequire = this.createVERSimpleLayout("25%");
@@ -180,9 +177,7 @@ define([
 
         sbPageContent.appendLine(accBoxRequire.toTagString());
 
-        // postfix code 입력 영역
-        sbPageContent.appendLine(this.createPostfixCode());
-
+        
         this.setPage(sbPageContent.toString());
         sbPageContent.clear();
 
@@ -275,10 +270,7 @@ define([
      */
     PythonCommon.prototype.generateCode = function(addCell = false, exec = false) {
         var code = new sb.StringBuilder();
-        var prefixCode = this.getPrefixCode();
-        if (prefixCode != '') {
-            code.appendLine(prefixCode);
-        }
+        
         var returnVar = $(this.wrapSelector('#vp_pyReturn')).val();
         if (returnVar != '') {
             code.appendFormat("{0} = ", returnVar);
@@ -310,11 +302,7 @@ define([
         // save argument metadata
         $(this.wrapSelector('#vp_pyArgMeta')).val(encodeURIComponent(JSON.stringify(argMeta)));
 
-        var postfixCode = this.getPostfixCode();
-        if (postfixCode != '') {
-            code.appendLine();
-            code.append(this.getPostfixCode());
-        }
+        
 
         if (addCell) {
             this.cellExecute(code.toString(), exec);
